#ifndef NT2_INCLUDE_FUNCTIONS_MTIMES_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MTIMES_HPP_INCLUDED

#include <nt2/linalg/include/functions/mtimes.hpp>

#endif
